@@ -33,6 +33,8 @@ class JitsiRestServlet(RestServlet):
         requester = await self.auth.get_user_by_req(request)
 
         jitsiUrl = self.hs.config.jitsi_url
+        jitsiAppID = self.hs.config.jitsi_app_id
+        jitsiAppSecret = self.hs.config.jitsi_app_secret
 
         return (
             200,
