@@ -23,7 +23,6 @@ from six.moves.urllib import parse as urlparse
 
 from canonicaljson import json
 
-from synapse import event_auth
 from synapse.api.constants import EventTypes, Membership
 from synapse.api.errors import (
     AuthError,
@@ -191,12 +190,6 @@ class RoomStateEventRestServlet(TransactionRestServlet):
 
         content = parse_json_object_from_request(request)
 
-        if event_type == EventTypes.Aliases:
-            # MSC2260
-            raise SynapseError(
-                400, "Cannot send m.room.aliases events via /rooms/{room_id}/state"
-            )
-
         event_dict = {
             "type": event_type,
             "content": content,
@@ -244,12 +237,6 @@ class RoomSendEventRestServlet(TransactionRestServlet):
         requester = await self.auth.get_user_by_req(request, allow_guest=True)
         content = parse_json_object_from_request(request)
 
-        if event_type == EventTypes.Aliases:
-            # MSC2260
-            raise SynapseError(
-                400, "Cannot send m.room.aliases events via /rooms/{room_id}/send"
-            )
-
         event_dict = {
             "type": event_type,
             "content": content,
@@ -923,19 +910,7 @@ class PurgeHistoryRestServlet(RestServlet):
         self.auth = hs.get_auth()
 
     async def on_POST(self, request, room_id, event_id):
-        # await assert_requester_is_admin(self.auth, request)
         requester = await self.auth.get_user_by_req(request)
-        power_level_event = await  self.auth.state.get_current_state(
-            room_id, EventTypes.PowerLevels, ""
-        )
-        power_level = 0
-        auth_events = {}
-        if power_level_event:
-            auth_events[(EventTypes.PowerLevels, "")] = power_level_event
-            power_level = event_auth.get_user_power_level(requester.user.to_string(), auth_events)
-
-        if power_level < 100:
-            raise SynapseError(403, "You don't have permission.")
 
         body = parse_json_object_from_request(request, allow_empty_body=True)
 
@@ -1014,8 +989,6 @@ class PurgeHistoryStatusRestServlet(RestServlet):
         self.auth = hs.get_auth()
 
     async def on_GET(self, request, purge_id):
-        # await assert_requester_is_admin(self.auth, request)
-
         purge_status = self.pagination_handler.get_purge_status(purge_id)
         if purge_status is None:
             raise NotFoundError("purge id '%s' not found" % purge_id)
